/*	mescc.h

	Mike's Enhanced Small C Compiler for Z80 & CP/M.

	Runtime library.

	Copyright (c) 1999-2015 Miguel I. Garcia Lopez / FloppySoftware, Spain

	This program is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation; either version 2, or (at your option) any
	later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

	Revisions:

	16 Jan 2001 : Last revision.
	23 Mar 2007 : Expand ccladr1 and ccladr2 for more speed.
	16 Apr 2007 : GPL'd.
	26 Aug 2012 : Added standard defs.
	08 Dec 2014 : Minor changes.
	09 Dec 2014 : Added support for stdin, stdout & stderr with CC_STDIO.
	12 Dec 2014 : Added support for stdin & stdout redirection in command line with CC_REDIR.
	16 Jan 2015 : Added SIZEOF_??? definitions.
	16 Feb 2015 : Modified / added code in cctmpw, ccxpb2, ccxpb, ccxpb3, ccxpw2
	              ccxpw, ccxpw3, ccladr2sv, ccladr2, ccladr1sv, ccladr1,
	              to avoid use of IX register.
	20 Mar 2015 : Added support for CC_NO_MUL, CC_NO_DIV, CC_NO_SWITCH, CC_NO_ARGS.
	12 Apr 2015 : Removed ccDEFARGS code.
	14 Jul 2015 : Modified code for << and >>, because a shift of 0 positions,
	              resulted in a wrong value (they assumed a shift > 0) - ie: 128 >> 0 resulted in 0.
	19 Oct 2015 : Improved multiplication algorithm (ccmul & ccumul).
	05 Nov 2015 : Modified ccsxt.
	30 Nov 2015 : Added support for atexit().
	24 Jan 2016 : Added support for CC_NO_ORG.

	Public:

	void exit(int code)

	Private:

	Too much to comment here.

	NOTES:

	This library file must be included first!

	Need following EQU's (generated by the compiler):

	ccSTACKSIZE	  Stack size in bytes.

	Supports following #defs:

	#define CC_STDIO     Support for stdin, stdout & stderr.
	#define CC_REDIR     Support for stdin & stdout redirection
	                     in command line (needs CC_STDIO).
	#define CC_NO_MUL    To exclude MULTIPLICATION code.
	#define CC_NO_DIV    To exclude DIVISION & MODULUS code.
	#define CC_NO_SWITCH To exclude SWITCH code.
	#define CC_NO_ARGS   To exclude ARGC & ARGV code.
	#define CC_NO_ORG    To exclude ORG 0100H code.
*/

/*	STANDARD DEFs
*/

#define BYTE	unsigned char
#define WORD	unsigned int
#define BOOL	char
#define NULL	0
#define TRUE	1
#define FALSE	0

#define SIZEOF_CHAR 1 /* [unsigned] char */
#define SIZEOF_INT  2 /* [unsigned] int */
#define SIZEOF_PTR  2 /* pointer */

